@@ -10,11 +10,31 @@ import (
 	"gopkg.in/yaml.v3"
 )
 
-func yamlToString(candidate *CandidateNode, prefs encoderPreferences) (string, error) {
+func configureEncoder(format PrinterOutputFormat, indent int) Encoder {
+	switch format {
+	case JsonOutputFormat:
+		return NewJsonEncoder(indent)
+	case PropsOutputFormat:
+		return NewPropertiesEncoder()
+	case CsvOutputFormat:
+		return NewCsvEncoder(',')
+	case TsvOutputFormat:
+		return NewCsvEncoder('\t')
+	case YamlOutputFormat:
+		return NewYamlEncoder(indent, false, true, true)
+	case XmlOutputFormat:
+		return NewXmlEncoder(indent, XmlPreferences.AttributePrefix, XmlPreferences.ContentName)
+	}
+	panic("invalid encoder")
+}
+
+func encodeToString(candidate *CandidateNode, prefs encoderPreferences) (string, error) {
 	var output bytes.Buffer
 	log.Debug("printing with indent: %v", prefs.indent)
 
-	printer := NewPrinterWithSingleWriter(bufio.NewWriter(&output), prefs.format, true, false, prefs.indent, true)
+	encoder := configureEncoder(prefs.format, prefs.indent)
+
+	printer := NewPrinter(encoder, NewSinglePrinterWriter(bufio.NewWriter(&output)))
 	err := printer.PrintResults(candidate.AsList())
 	return output.String(), err
 }
@@ -36,7 +56,7 @@ func encodeOperator(d *dataTreeNavigator, context Context, expressionNode *Expre
 
 	for el := context.MatchingNodes.Front(); el != nil; el = el.Next() {
 		candidate := el.Value.(*CandidateNode)
-		stringValue, err := yamlToString(candidate, preferences)
+		stringValue, err := encodeToString(candidate, preferences)
 
 		if err != nil {
 			return Context{}, err
@@ -68,9 +88,23 @@ func encodeOperator(d *dataTreeNavigator, context Context, expressionNode *Expre
 	return context.ChildContext(results), nil
 }
 
+type decoderPreferences struct {
+	format InputFormat
+}
+
 /* takes a string and decodes it back into an object */
 func decodeOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
 
+	preferences := expressionNode.Operation.Preferences.(decoderPreferences)
+
+	var decoder Decoder
+	switch preferences.format {
+	case YamlInputFormat:
+		decoder = NewYamlDecoder()
+	case XmlInputFormat:
+		decoder = NewXmlDecoder(XmlPreferences.AttributePrefix, XmlPreferences.ContentName)
+	}
+
 	var results = list.New()
 	for el := context.MatchingNodes.Front(); el != nil; el = el.Next() {
 		candidate := el.Value.(*CandidateNode)
@@ -79,7 +113,9 @@ func decodeOperator(d *dataTreeNavigator, context Context, expressionNode *Expre
 
 		var dataBucket yaml.Node
 		log.Debugf("got: [%v]", candidate.Node.Value)
-		decoder := yaml.NewDecoder(strings.NewReader(unwrapDoc(candidate.Node).Value))
+
+		decoder.Init(strings.NewReader(unwrapDoc(candidate.Node).Value))
+
 		errorReading := decoder.Decode(&dataBucket)
 		if errorReading != nil {
 			return Context{}, errorReading
