@@ -25,6 +25,7 @@ const (
 	PropsOutputFormat
 	CsvOutputFormat
 	TsvOutputFormat
+	XmlOutputFormat
 )
 
 func OutputFormatFromString(format string) (PrinterOutputFormat, error) {
@@ -39,40 +40,30 @@ func OutputFormatFromString(format string) (PrinterOutputFormat, error) {
 		return CsvOutputFormat, nil
 	case "tsv", "t":
 		return TsvOutputFormat, nil
+	case "xml", "x":
+		return XmlOutputFormat, nil
 	default:
-		return 0, fmt.Errorf("unknown format '%v' please use [yaml|json|props|csv|tsv]", format)
+		return 0, fmt.Errorf("unknown format '%v' please use [yaml|json|props|csv|tsv|xml]", format)
 	}
 }
 
 type resultsPrinter struct {
-	outputFormat       PrinterOutputFormat
-	unwrapScalar       bool
-	colorsEnabled      bool
-	indent             int
-	printDocSeparators bool
-	printerWriter      PrinterWriter
-	firstTimePrinting  bool
-	previousDocIndex   uint
-	previousFileIndex  int
-	printedMatches     bool
-	treeNavigator      DataTreeNavigator
-	appendixReader     io.Reader
+	encoder           Encoder
+	printerWriter     PrinterWriter
+	firstTimePrinting bool
+	previousDocIndex  uint
+	previousFileIndex int
+	printedMatches    bool
+	treeNavigator     DataTreeNavigator
+	appendixReader    io.Reader
 }
 
-func NewPrinterWithSingleWriter(writer io.Writer, outputFormat PrinterOutputFormat, unwrapScalar bool, colorsEnabled bool, indent int, printDocSeparators bool) Printer {
-	return NewPrinter(NewSinglePrinterWriter(writer), outputFormat, unwrapScalar, colorsEnabled, indent, printDocSeparators)
-}
-
-func NewPrinter(printerWriter PrinterWriter, outputFormat PrinterOutputFormat, unwrapScalar bool, colorsEnabled bool, indent int, printDocSeparators bool) Printer {
+func NewPrinter(encoder Encoder, printerWriter PrinterWriter) Printer {
 	return &resultsPrinter{
-		printerWriter:      printerWriter,
-		outputFormat:       outputFormat,
-		unwrapScalar:       unwrapScalar,
-		colorsEnabled:      colorsEnabled,
-		indent:             indent,
-		printDocSeparators: outputFormat == YamlOutputFormat && printDocSeparators,
-		firstTimePrinting:  true,
-		treeNavigator:      NewDataTreeNavigator(),
+		encoder:           encoder,
+		printerWriter:     printerWriter,
+		firstTimePrinting: true,
+		treeNavigator:     NewDataTreeNavigator(),
 	}
 }
 
@@ -87,26 +78,7 @@ func (p *resultsPrinter) PrintedAnything() bool {
 func (p *resultsPrinter) printNode(node *yaml.Node, writer io.Writer) error {
 	p.printedMatches = p.printedMatches || (node.Tag != "!!null" &&
 		(node.Tag != "!!bool" || node.Value != "false"))
-
-	var encoder Encoder
-	if node.Kind == yaml.ScalarNode && p.unwrapScalar && p.outputFormat == YamlOutputFormat {
-		return writeString(writer, node.Value+"\n")
-	}
-
-	switch p.outputFormat {
-	case JsonOutputFormat:
-		encoder = NewJsonEncoder(writer, p.indent)
-	case PropsOutputFormat:
-		encoder = NewPropertiesEncoder(writer)
-	case CsvOutputFormat:
-		encoder = NewCsvEncoder(writer, ',')
-	case TsvOutputFormat:
-		encoder = NewCsvEncoder(writer, '\t')
-	case YamlOutputFormat:
-		encoder = NewYamlEncoder(writer, p.indent, p.colorsEnabled)
-	}
-
-	return encoder.Encode(node)
+	return p.encoder.Encode(writer, node)
 }
 
 func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
@@ -117,7 +89,7 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 		return nil
 	}
 
-	if p.outputFormat != YamlOutputFormat {
+	if !p.encoder.CanHandleAliases() {
 		explodeOp := Operation{OperationType: explodeOpType}
 		explodeNode := ExpressionNode{Operation: &explodeOp}
 		context, err := p.treeNavigator.GetMatchingNodes(Context{MatchingNodes: matchingNodes}, &explodeNode)
@@ -137,7 +109,7 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 	for el := matchingNodes.Front(); el != nil; el = el.Next() {
 
 		mappedDoc := el.Value.(*CandidateNode)
-		log.Debug("-- print sep logic: p.firstTimePrinting: %v, previousDocIndex: %v, mappedDoc.Document: %v, printDocSeparators: %v", p.firstTimePrinting, p.previousDocIndex, mappedDoc.Document, p.printDocSeparators)
+		log.Debug("-- print sep logic: p.firstTimePrinting: %v, previousDocIndex: %v, mappedDoc.Document: %v", p.firstTimePrinting, p.previousDocIndex, mappedDoc.Document)
 
 		writer, errorWriting := p.printerWriter.GetWriter(mappedDoc)
 		if errorWriting != nil {
@@ -147,14 +119,13 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 		commentsStartWithSepExp := regexp.MustCompile(`^\$yqDocSeperator\$`)
 		commentStartsWithSeparator := commentsStartWithSepExp.MatchString(mappedDoc.LeadingContent)
 
-		if (p.previousDocIndex != mappedDoc.Document || p.previousFileIndex != mappedDoc.FileIndex) && p.printDocSeparators && !commentStartsWithSeparator {
-			log.Debug("-- writing doc sep")
-			if err := writeString(writer, "---\n"); err != nil {
+		if (p.previousDocIndex != mappedDoc.Document || p.previousFileIndex != mappedDoc.FileIndex) && !commentStartsWithSeparator {
+			if err := p.encoder.PrintDocumentSeparator(writer); err != nil {
 				return err
 			}
 		}
 
-		if err := processLeadingContent(mappedDoc, writer, p.printDocSeparators, p.outputFormat); err != nil {
+		if err := p.encoder.PrintLeadingContent(writer, mappedDoc.LeadingContent); err != nil {
 			return err
 		}
 
@@ -166,9 +137,11 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 		if err := writer.Flush(); err != nil {
 			return err
 		}
+		log.Debugf("done printing results")
 	}
 
-	if p.appendixReader != nil && p.outputFormat == YamlOutputFormat {
+	// what happens if I remove output format check?
+	if p.appendixReader != nil {
 		writer, err := p.printerWriter.GetWriter(nil)
 		if err != nil {
 			return err
