@@ -38,43 +38,6 @@ func writeString(writer io.Writer, txt string) error {
 	return errorWriting
 }
 
-func processLeadingContent(mappedDoc *CandidateNode, writer io.Writer, printDocSeparators bool, outputFormat PrinterOutputFormat) error {
-	log.Debug("headcommentwas %v", mappedDoc.LeadingContent)
-	log.Debug("finished headcomment")
-	reader := bufio.NewReader(strings.NewReader(mappedDoc.LeadingContent))
-
-	for {
-
-		readline, errReading := reader.ReadString('\n')
-		if errReading != nil && !errors.Is(errReading, io.EOF) {
-			return errReading
-		}
-		if strings.Contains(readline, "$yqDocSeperator$") {
-			if printDocSeparators {
-				if err := writeString(writer, "---\n"); err != nil {
-					return err
-				}
-			}
-		} else if outputFormat == YamlOutputFormat {
-			if err := writeString(writer, readline); err != nil {
-				return err
-			}
-		}
-
-		if errors.Is(errReading, io.EOF) {
-			if readline != "" {
-				// the last comment we read didn't have a new line, put one in
-				if err := writeString(writer, "\n"); err != nil {
-					return err
-				}
-			}
-			break
-		}
-	}
-
-	return nil
-}
-
 func processReadStream(reader *bufio.Reader) (io.Reader, string, error) {
 	var commentLineRegEx = regexp.MustCompile(`^\s*#`)
 	var sb strings.Builder
@@ -107,8 +70,8 @@ func processReadStream(reader *bufio.Reader) (io.Reader, string, error) {
 	}
 }
 
-func readDocuments(reader io.Reader, filename string, fileIndex int) (*list.List, error) {
-	decoder := yaml.NewDecoder(reader)
+func readDocuments(reader io.Reader, filename string, fileIndex int, decoder Decoder) (*list.List, error) {
+	decoder.Init(reader)
 	inputList := list.New()
 	var currentIndex uint
 
